@@ -9,6 +9,6 @@ setGeneric("getPar", function(object) standardGeneric("getPar"))
 setGeneric("getInflexion", function(object) standardGeneric("getInflexion"))
 setGeneric("getGoodness", function(object) standardGeneric("getGoodness"))
 setGeneric("getStdErr", function(object) standardGeneric("getStdErr"))
-setGeneric("getNlmErr", function(object) standardGeneric("getNlmErr"))
+#setGeneric("getNlmErr", function(object) standardGeneric("getNlmErr"))
 setGeneric("getAUC", function(object) standardGeneric("getAUC"))
 setGeneric("getEstimates", function(object, targets=seq(.9, .1, by=-.1), B=1e4, conf.level=.95) standardGeneric("getEstimates"))
