@@ -11,7 +11,7 @@ setMethod("getPar", "nplr", function(object){
     })
 setMethod('getGoodness', 'nplr', function(object) return(object@goodness))
 setMethod('getStdErr', 'nplr', function(object) return(object@stdErr))
-setMethod("getNlmErr", "nplr", function(object) return(object@nlmErr))
+#setMethod("getNlmErr", "nplr", function(object) return(object@nlmErr))
 setMethod("getAUC", "nplr", function(object) return(object@AUC))
 
 
@@ -122,15 +122,18 @@ nplr <- function(x, y, useLog=TRUE, LPweight=0.25,
     if(length(unique(signif(yFit, 5)))==1)
         stop("nplr failed and returned constant fitted values.
             Your data may not be appropriate for such model.")
-
-    perf <- .getPerf(y, yFit)
     
     # Inflexion point coordinates
     pars <- cbind.data.frame(bottom=bottom, top=top, xmid=xmid, scal=scal, s=s)
     infl <- .inflPoint(pars)
   
-    object@w <- (y - yFit)^2
-#    object@nlmErr <- ifelse(npars=="all", testAll$err, NA)
+    # Performances
+    w <- .weight(x, y, yFit, LPweight)
+    perf <- .getPerf(y, yFit, w)
+    # err <- sum((y - yFit)^2)
+    # weightedErr <- sum(w/sum(w)*(y - yFit)^2)
+
+    object@w <- w
     object@npars <- npars
     object@pars <- pars
     object@yFit <- yFit
@@ -138,7 +141,7 @@ nplr <- function(x, y, useLog=TRUE, LPweight=0.25,
     object@yCurve <- newY
     object@inflPoint <- infl
     object@goodness <- perf$goodness
-    object@stdErr <- perf$stdErr
+    object@stdErr <- c(stdErr = perf$stdErr, "weighted stdErr" = perf$wStdErr)
     object@AUC <- data.frame(trapezoid = .AUC(newX, newY), Simpson = .Simpson(newX, newY))
   
     return(object)
